@@ -13,7 +13,9 @@ class AnalyzedStrategies:
     utility_dependent : list of :class:`Strategy`
         List of the strategies where the equilibrium depends on the exact utilities.
     inconclusive : list of :class:`Strategy`
-        List of the strategies where we are not able to decide whether it is an equilibrium or not.
+        List of the strategies where we are not able to decide whether it is an equilibrium or not. In the current
+        version of the package, this argument is not used anymore, because we are always able to decide whether
+        a strategy is an equilibrium or not.
     non_equilibria : list of :class:`Strategy`
         List of the strategies where the program certifies there is no equilibrium.
 
@@ -22,10 +24,10 @@ class AnalyzedStrategies:
         >>> from poisson_approval import StrategyOrdinal, ProfileOrdinal
         >>> profile = ProfileOrdinal({'abc': 0.2, 'acb': 0.3, 'bac': 0.5})
         >>> analyzed_strategies = AnalyzedStrategies(
-        ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile)],
-        ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile)],
-        ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile)],
-        ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile)]
+        ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile=profile)],
+        ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile=profile)],
+        ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile=profile)],
+        ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile=profile)]
         ... )
         >>> print(analyzed_strategies.winners_at_equilibrium)
         a, b
@@ -46,14 +48,14 @@ class AnalyzedStrategies:
             >>> from poisson_approval import StrategyOrdinal, ProfileOrdinal
             >>> profile = ProfileOrdinal({'abc': Fraction(2, 10), 'acb': Fraction(3, 10), 'bac': Fraction(5, 10)})
             >>> analyzed_strategies = AnalyzedStrategies(
-            ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile),
-            ...                 StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'ab'}, profile)],
-            ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile),
-            ...                        StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'ab'}, profile)],
-            ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile),
-            ...                     StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'ab'}, profile)],
-            ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile),
-            ...                   StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'ab'}, profile)]
+            ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile=profile),
+            ...                 StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'ab'}, profile=profile)],
+            ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile=profile),
+            ...                        StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'ab'}, profile=profile)],
+            ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile=profile),
+            ...                     StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'ab'}, profile=profile)],
+            ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile=profile),
+            ...                   StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'ab'}, profile=profile)]
             ... )
             >>> analyzed_strategies
             Equilibria:
@@ -75,10 +77,10 @@ class AnalyzedStrategies:
         With singulars ("equilibrium"):
 
             >>> analyzed_strategies = AnalyzedStrategies(
-            ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile)],
-            ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile)],
-            ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile)],
-            ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile)]
+            ...     equilibria=[StrategyOrdinal({'abc': 'a', 'acb': 'a', 'bac': 'b'}, profile=profile)],
+            ...     utility_dependent=[StrategyOrdinal({'abc': 'a', 'acb': 'ac', 'bac': 'b'}, profile=profile)],
+            ...     non_equilibria=[StrategyOrdinal({'abc': 'ab', 'acb': 'a', 'bac': 'b'}, profile=profile)],
+            ...     inconclusive=[StrategyOrdinal({'abc': 'ab', 'acb': 'ac', 'bac': 'b'}, profile=profile)]
             ... )
             >>> analyzed_strategies
             Equilibrium:
