@@ -1,3 +1,4 @@
+import pickle
 import ternary
 from math import floor, ceil
 from fractions import Fraction
@@ -55,24 +56,44 @@ def _generate_heatmap_data(f, scale):
     return d_scaled_point_color, d_point_values
 
 
-def ternary_figure(size_inches='auto', scale=None, boundary_width=1.0, **kwargs):  # pragma: no cover
-    """Create a ternary plot (adaptation of `figure` from the package python-ternary).
+def ternary_figure(size_inches='auto', scale=None, boundary_width=1.0, **kwargs):
+    """Create a ternary plot (adaptation of ``figure`` from the package `python-ternary`).
 
     Parameters
     ----------
     size_inches : tuple or str
-        The horizontal and vertical sizes of the figure, in inches. If 'auto', we will try to do our best.
+        The horizontal and vertical sizes of the figure, in inches. If ``'auto'``, we will try to do our best.
     scale : Number
         The scale of the figure. The higher it is, the higher the resolution of the heatmap for example.
     boundary_width
         Width of the line representing the boundary of the triangle.
     kwargs
-        Other keyword arguments are passed to the function `figure` of the package python-ternary.
+        Other keyword arguments are passed to the function ``figure`` of the package `python-ternary`.
 
     Returns
     -------
     figure : matplotlib.figure.Figure
-    ternary_ax : TernaryAxesSubplotPoisson
+    ternary_ax : :class:`TernaryAxesSubplotPoisson`
+
+    Examples
+    --------
+    Grid and lines:
+
+        >>> figure, tax = ternary_figure()
+        >>> tax.gridlines_simplex(multiple=0.1)
+        >>> tax.horizontal_line_simplex(0.1)
+        >>> tax.left_parallel_line_simplex(0.2)
+        >>> tax.right_parallel_line_simplex(0.3)
+        >>> tax.line_simplex((1, 0, 0), (0.2, 0.5, 0.3))
+
+    Titles and annotations:
+
+        >>> figure, tax = ternary_figure()
+        >>> tax.set_title_padded('The title of the figure')
+        >>> tax.right_corner_label('The right label')
+        >>> tax.top_corner_label('The top label')
+        >>> tax.left_corner_label('The left label')
+        >>> tax.annotate_simplex('An annotation', (0.33, 0.33, 0.33))
     """
     ternary_ax = TernaryAxesSubplotPoisson(scale=scale, size_inches=size_inches, **kwargs)
     figure = ternary_ax.get_figure()
@@ -85,11 +106,11 @@ def ternary_figure(size_inches='auto', scale=None, boundary_width=1.0, **kwargs)
     return figure, ternary_ax
 
 
-class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
-    """Subclass of `TernaryAxesSubplot`, defined in the package python-ternary.
+class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):
+    """Subclass of ``TernaryAxesSubplot``, defined in the package `python-ternary`.
 
-    This class implements some additional methods for Poisson Approval. For some examples, cf. the tutorial
-    in section "Meta-Analysis".
+    This class implements some additional methods for Poisson Approval. For some examples, cf. the corresponding
+    tutorial.
     """
 
     def __init__(self, scale=None, size_inches='auto', **kwargs):
@@ -128,13 +149,13 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         return [self._scaled_number(x) for x in p]
 
     def set_title_padded(self, title, **kwargs):
-        """Adaptation of `set_title`.
+        """Adaptation of ``set_title``.
 
         Adjust the position of the title to avoid collision with the label of the top corner.
 
-        Parameters
-        ----------
-        Cf. `set_title` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``set_title`` in `python-ternary`.
         """
         size_inches = plt.gcf().get_size_inches()
         pad = 6 * size_inches[1]
@@ -142,78 +163,78 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         self.set_title(title, pad=pad, **kwargs)
 
     def annotate_simplex(self, text, position, horizontalalignment='center', verticalalignment='center', **kwargs):
-        """Adaptation of `annotate`.
+        """Adaptation of ``annotate``.
 
         * The input position is in the simplex (instead of the scaled simplex), i.e. coordinates are in [0, 1].
         * The default horizontal and vertical alignments are centered.
 
-        Parameters
-        ----------
-        Cf. `annotate` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``annotate`` in `python-ternary`.
         """
         self.annotate(text, position=self._scaled_position(position),
                       horizontalalignment=horizontalalignment, verticalalignment=verticalalignment, **kwargs)
 
     def gridlines_simplex(self, multiple=None, horizontal_kwargs=None, left_kwargs=None,
                           right_kwargs=None, **kwargs):
-        """Adaptation of `gridlines`.
+        """Adaptation of ``gridlines``.
 
         * The argument `multiple` is a grid step in [0, 1] (instead of [0, scale]).
 
-        Parameters
-        ----------
-        Cf. `gridlines` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``gridlines`` in `python-ternary`.
         """
         self.gridlines(multiple=self._scaled_number(multiple), horizontal_kwargs=horizontal_kwargs,
                        left_kwargs=left_kwargs, right_kwargs=right_kwargs, **kwargs)
 
     def line_simplex(self, p1, p2, color='black', **kwargs):
-        """Adaptation of `line`.
+        """Adaptation of ``line``.
 
         * The input positions are in the simplex (instead of the scaled simplex), i.e. coordinates are in [0, 1].
 
-        Parameters
-        ----------
-        Cf. `line` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``line`` in `python-ternary`.
         """
         self.line(self._scaled_position(p1), self._scaled_position(p2), color=color, **kwargs)
 
     def horizontal_line_simplex(self, i, color='black', **kwargs):
-        """Adaptation of `horizontal_line`.
+        """Adaptation of ``horizontal_line``.
 
         * The argument `i` is in [0, 1] (instead of [0, scale]).
 
-        Parameters
-        ----------
-        Cf. `horizontal_line` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``horizontal_line`` in `python-ternary`.
         """
         self.horizontal_line(self._scaled_number(i), color=color, **kwargs)
 
     def left_parallel_line_simplex(self, i, color='black', **kwargs):
-        """Adaptation of `left_parallel_line`.
+        """Adaptation of ``left_parallel_line``.
 
         * The argument `i` is in [0, 1] (instead of [0, scale]).
 
-        Parameters
-        ----------
-        Cf. `left_parallel_line` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``left_parallel_line`` in `python-ternary`.
         """
         self.left_parallel_line(self._scaled_number(i), color=color, **kwargs)
 
     def right_parallel_line_simplex(self, i, color='black', **kwargs):
-        """Adaptation of `right_parallel_line`.
+        """Adaptation of ``right_parallel_line``.
 
         * The argument `i` is in [0, 1] (instead of [0, scale]).
 
-        Parameters
-        ----------
-        Cf. `right_parallel_line` in python-ternary.
+        Notes
+        -----
+        For the parameters, cf. ``right_parallel_line`` in `python-ternary`.
         """
         self.right_parallel_line(self._scaled_number(i), color=color, **kwargs)
 
     def heatmap_intensity(self, func, right_label, top_label, left_label,
                           style='hexagonal', cmap='plasma', **kwargs):
-        """Adaptation of `heatmapf`.
+        """Adaptation of ``heatmapf``.
 
         Parameters
         ----------
@@ -227,11 +248,22 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         left_label : str
             Label of the left corner.
         style : str
-            Contrarily to default settings in python-ternary, the default is ``'hexagonal'``.
+            Contrarily to default settings in `python-ternary`, the default is ``'hexagonal'``.
         cmap : str
-            Colormap. Contrarily to default settings in python-ternary, the default is ``'plasma'``.
+            Colormap. Contrarily to default settings in `python-ternary`, the default is ``'plasma'``.
         kwargs
-            All other keywords arguments are passed to method ``heatmapf`` of python-ternary.
+            All other keywords arguments are passed to method ``heatmapf`` of `python-ternary`.
+
+        Examples
+        --------
+            >>> def f(right, top, left):
+            ...     return (right**2 + top) / (left + 1)
+            >>> figure, tax = ternary_figure(scale=10)
+            >>> tax.heatmap_intensity(f,
+            ...                       left_label='left',
+            ...                       right_label='right',
+            ...                       top_label='top')
+            >>> tax.set_title_padded('An intensity heat map')
         """
         default_pad = 0.15
         if 'cb_kwargs' not in kwargs.keys():
@@ -246,7 +278,8 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
             plt.gcf().set_size_inches(7, 5)
 
     def heatmap_candidates(self, func, right_label, top_label, left_label, legend_title='',
-                           legend_style='palette', style='hexagonal', colorbar=False, **kwargs):
+                           legend_style='palette', style='hexagonal', colorbar=False, file_save_data = None,
+                           **kwargs):
         """Heatmap of a function from the simplex to 3D vectors.
 
         Parameters
@@ -266,13 +299,39 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
             The style of the legend. The two available options are ``'palette'`` and ``'color_patches'``.
             Cf. :meth:`legend_palette` and :meth:`legend_color_patches`.
         style
-            Contrarily to default settings in python-ternary, the default is ``'hexagonal'``.
+            Contrarily to default settings in `python-ternary`, the default is ``'hexagonal'``.
         colorbar
-            Contrarily to default settings in python-ternary, the default is False.
+            Contrarily to default settings in `python-ternary`, the default is False.
+        file_save_data : str
+            File where the computed data will be saved (using ``pickle``).
         kwargs
-            All other keywords arguments are passed to method ``heatmap`` of python-ternary.
+            All other keywords arguments are passed to method ``heatmap`` of `python-ternary`.
+
+        Examples
+        --------
+            >>> def g(right, top, left):
+            ...     a = top**.5
+            ...     b = left**2.
+            ...     c = 1 - a - b
+            ...     return [a, b, c]
+            >>> figure, tax = ternary_figure(scale=5)
+            >>> tax.heatmap_candidates(g,
+            ...                        left_label='left',
+            ...                        right_label='right',
+            ...                        top_label='top',
+            ...                        legend_title='Candidates',
+            ...                        legend_style='palette')
+            >>> tax.set_title_padded('A candidate heat map')
+
+        To retrieve the computed value that is closest to a given point:
+
+            >>> tax.f_point_values_(right=0.5, top=0.3, left=0.2)
+            [0.4472135954999579, 0.04000000000000001, 0.5127864045000421]
         """
         d_scaled_point_color, self.d_point_values_ = _generate_heatmap_data(func, self.get_scale())
+        if file_save_data is not None:
+            with open(file_save_data, "wb") as f:
+                pickle.dump([d_scaled_point_color, self.d_point_values_], f)
         self.heatmap(d_scaled_point_color, style=style, colorbar=colorbar, use_rgba=True, **kwargs)
         self.right_corner_label(right_label)
         self.top_corner_label(top_label)
@@ -288,9 +347,9 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         """Data of a candidate heatmap.
 
         This function can be used only after a candidate heatmap has been drawn. When given a point of the simplex,
-        it considers the closest point where f was computed and returns the corresponding value. It does not
-        recompute f, and in particular the result may not be the same as a direct application of f to the point given
-        as input.
+        it considers the closest point where `f` was computed and returns the corresponding value. It does not
+        recompute `f`, and in particular the result may not be the same as a direct application of `f` to the point
+        given as input.
 
         Parameters
         ----------
@@ -300,8 +359,8 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
 
         Returns
         -------
-        array of size 3
-            The value associated respectively to each candidate a, b, c.
+        list
+            List of size 3. The value associated respectively to each candidate `a`, `b`, `c`.
         """
         if self.d_point_values_ is None:
             raise ValueError("No candidate heatmap has been defined")
@@ -346,12 +405,12 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         """
         try:
             draw_condorcet_zones(self, right_order, top_order, left_order, d_order_fixed_share)
-        except NameError:
+        except NameError:  # pragma: no cover
             self._annotate_condorcet_old(right_order, top_order, left_order, d_order_fixed_share)
 
-    def _annotate_condorcet_old(self, right_ranking, top_ranking, left_ranking, d_order_fixed_share):
+    def _annotate_condorcet_old(self, right_ranking, top_ranking, left_ranking, d_order_fixed_share=None):
         """Old version, for rankings only"""
-        if d_order_fixed_share is not None:
+        if d_order_fixed_share:
             raise NotImplementedError
         count_candidate_tops = dict(Counter([
             ranking[0] for ranking in [right_ranking, top_ranking, left_ranking]]))
@@ -421,14 +480,14 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
         title : str
             Title of the legend.
         all_mixes : bool
-            If True, then all mixes are indicated in the legend: a + b, a + c, b + c and a + b + c.
+            If True, then all mixes are indicated in the legend: `a + b`, `a + c`, `b + c` and `a + b + c`.
         data : dict, optional
             Key : anything. Value: a tuple, list, etc giving an RGB or RGBA code. This is used only if `all_mixes`
             is False.
 
         Notes
         -----
-        * The color patches for single candidates a, b, c are in the legend anyway.
+        * The color patches for single candidates `a`, `b`, `c` are in the legend anyway.
         * If `all_mixes` is True, then all mixes are indicated in the legend.
         * If `all_mixes` is False and `data` is given, then if at least a value is close to a perfect mix (like half
           of `a` and half of `b`), then this mix is added to the legend.
@@ -466,7 +525,7 @@ class TernaryAxesSubplotPoisson(ternary.TernaryAxesSubplot):  # pragma: no cover
 
         Notes
         -----
-        This is rather a hack than a real matplotlib legend. Hence the usual commands to choose the position
+        This is more a hack than a real `matplotlib` legend. Hence the usual commands to choose the position
         of the legend, for example, are not meant to work here.
         """
         legend_ax = plt.gcf().add_axes([.68, .63, .2, .2], facecolor='k')
