@@ -5,7 +5,7 @@ import numpy as np
 import sympy as sp
 from fractions import Fraction
 from decimal import Decimal
-from poisson_approval.constants.constants import *
+from poisson_approval.constants.basic_constants import *
 from poisson_approval.utils.DictPrintingInOrder import DictPrintingInOrder
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 
@@ -33,7 +33,7 @@ def rand_simplex(d=6):
     Returns
     -------
     numpy.ndarray
-        A numpy array of length `d`, whose sum is 1.
+        A `numpy` array of length `d`, whose sum is 1.
 
     Examples
     --------
@@ -58,7 +58,7 @@ def rand_integers_fixed_sum(d, fixed_sum):
     Returns
     -------
     numpy.ndarray
-        A numpy array of `d` integers, whose sum is `fixed_sum`, and drawn uniformly.
+        A `numpy` array of `d` integers, whose sum is `fixed_sum`, and drawn uniformly.
 
     Examples
     --------
@@ -87,7 +87,7 @@ def rand_simplex_grid(d, denominator):
     Returns
     -------
     numpy.ndarray
-        A numpy array of length `d`, whose coordinates are fractions of the given denominator, and whose sum is 1.
+        A `numpy` array of length `d`, whose coordinates are fractions of the given denominator, and whose sum is 1.
 
     Examples
     --------
@@ -105,14 +105,14 @@ def probability(factory, n_samples, test, conditional_on=None):
 
     Parameters
     ----------
-    factory : callable or tuple
+    factory : callable or tuple of callable
         This can be:
 
         * Either a callable that takes no input and that outputs a (random) `something`,
         * Or a tuple of such factories (cf. examples below).
     n_samples : int
         Number of samples.
-    test : callable or tuple
+    test : callable or tuple of callable
         This can be:
 
         * Either a function that take as input(s) the output(s) of the factory(ies) and that returns a Boolean.
@@ -123,12 +123,12 @@ def probability(factory, n_samples, test, conditional_on=None):
 
     Returns
     -------
-    float or tuple
+    float or tuple of float
         This can be:
 
         * Either the probability that the output(s) generated by `factory` meet(s) `test`, conditional on the fact
           that it meets `conditional_on`, based on a Monte-Carlo estimation of `n_samples` trials.
-        * Either a tuple giving this probability for each member of `test`, when `test` is a tuple itself.
+        * Or a tuple giving this probability for each member of `test`, when `test` is a tuple itself.
 
     Examples
     --------
@@ -169,7 +169,7 @@ def probability(factory, n_samples, test, conditional_on=None):
         ...             test=(lambda x: x > .5, lambda x: x > .75), conditional_on=lambda x: x > .25)
         (0.661, 0.332)
 
-    When using a tuple of tests, the same samples are used to estimate each probability.
+    When using a tuple of tests, the same sample is used to estimate each probability.
     """
     if not isinstance(factory, tuple):
         factory = (factory,)
@@ -193,7 +193,7 @@ def probability(factory, n_samples, test, conditional_on=None):
 
 
 def image_distribution(factory, n_samples, f, conditional_on=None):
-    """Distribution of ``f(something)`` for a random `something`.
+    """Distribution of `f(something)` for a random `something`.
 
     Parameters
     ----------
@@ -286,7 +286,7 @@ def isnan(x):
 
     Notes
     -----
-    This extends the usual numpy function ``isnan`` to fractions and sympy expressions.
+    This extends the usual `numpy` function ``isnan`` to fractions and `sympy` expressions.
 
     Examples
     --------
@@ -318,7 +318,7 @@ def isposinf(x):
 
     Notes
     -----
-    This extends the usual numpy function ``isposinf`` to fractions and sympy expressions.
+    This extends the usual `numpy` function ``isposinf`` to fractions and `sympy` expressions.
 
     Examples
     --------
@@ -350,7 +350,7 @@ def isneginf(x):
 
     Notes
     -----
-    This extends the usual numpy function ``isneginf`` to fractions and sympy expressions.
+    This extends the usual `numpy` function ``isneginf`` to fractions and `sympy` expressions.
 
     Examples
     --------
@@ -377,7 +377,7 @@ def give_figure(n, singular, plural=None):
     singular : str
         The singular word.
     plural : str
-        The plural word. Default: the singular with a final 's'.
+        The plural word. Default: the singular with a final "s".
 
     Returns
     -------
@@ -510,8 +510,8 @@ def candidates_to_probabilities(candidates):
 
     Returns
     -------
-    ndarray
-        Array of size 3. For example, the first coefficient is the probability that candidate `a` win by a random
+    numpy.ndarray
+        Array of size 3. For example, the first coefficient is the probability that candidate `a` wins by a random
         tie-break.
 
     Examples
@@ -529,7 +529,7 @@ def array_to_d_candidate_value(values):
 
     Parameters
     ----------
-    values : ndarray
+    values : numpy.ndarray
         An array of size 3.
 
     Returns
@@ -556,7 +556,7 @@ def d_candidate_value_to_array(d_candidate_value):
 
     Returns
     -------
-    ndarray
+    numpy.ndarray
         The corresponding array.
 
     Examples
@@ -571,7 +571,7 @@ def d_candidate_value_to_array(d_candidate_value):
 def one_over_t(t):
     """Function `1 / t`.
 
-    When used as an update ratio (cf. :meth:`ProfileCardinal.fictitious_play`), this amounts to computing the arithmetic
+    When used as an update ratio (cf. :meth:`~poisson_approval.ProfileCardinal.fictitious_play`), this amounts to computing the arithmetic
     mean.
 
     Parameters
@@ -581,6 +581,7 @@ def one_over_t(t):
     Returns
     -------
     Number
+        `1 / t`.
 
     Examples
     --------
@@ -593,7 +594,7 @@ def one_over_t(t):
 def one_over_sqrt_t(t):
     """Function `1 / sqrt(t)`.
 
-    This function is provided as an example of update ratio for :meth:`ProfileCardinal.fictitious_play`.
+    This function is provided as an example of update ratio for :meth:`~poisson_approval.ProfileCardinal.fictitious_play`.
 
     Parameters
     ----------
@@ -602,6 +603,7 @@ def one_over_sqrt_t(t):
     Returns
     -------
     Number
+        `1 / sqrt(t)`.
 
     Examples
     --------
@@ -614,8 +616,9 @@ def one_over_sqrt_t(t):
 def one_over_log_t_plus_one(t):
     """Function `1 / log(t + 1)`.
 
-    This function is provided as an example of update ratio for :meth:`ProfileCardinal.fictitious_play`. The constant
-    1 in the denominator is the smallest integer such that `f(t = 2) < 1`.
+    This function is provided as an example of update ratio for
+    :meth:`~poisson_approval.ProfileCardinal.fictitious_play`. The constant 1 in the denominator is the smallest
+    integer such that `f(t = 2) < 1`.
 
     Parameters
     ----------
@@ -624,6 +627,7 @@ def one_over_log_t_plus_one(t):
     Returns
     -------
     Number
+        `1 / log(t + 1)`.
 
     Examples
     --------
@@ -636,8 +640,9 @@ def one_over_log_t_plus_one(t):
 def one_over_log_log_t_plus_fourteen(t):
     """Function `1 / log(log(t + 14))`.
 
-    This function is provided as an example of update ratio for :meth:`ProfileCardinal.fictitious_play`. The constant
-    14 in the denominator is the smallest integer such that `f(t = 1) < 1`.
+    This function is provided as an example of update ratio for
+    :meth:`~poisson_approval.ProfileCardinal.fictitious_play`. The constant 14 in the denominator is the smallest
+    integer such that `f(t = 2) < 1`.
 
     Parameters
     ----------
@@ -646,6 +651,7 @@ def one_over_log_log_t_plus_fourteen(t):
     Returns
     -------
     Number
+        `1 / log(log(t + 14))`.
 
     Examples
     --------
@@ -661,8 +667,7 @@ def my_division(x, y):
 
     Parameters
     ----------
-    x : Number
-    y : Number
+    x,y : Number
 
     Returns
     -------
@@ -685,7 +690,7 @@ def my_division(x, y):
         >>> my_division(0.1, Fraction(5, 2))
         0.04
 
-    If `x` and `y` are integers, decimals, fractions or sympy expressions, then the result is symbolic:
+    If `x` and `y` are integers, decimals, fractions or `sympy` expressions, then the result is symbolic:
 
         >>> my_division(2, Fraction(5, 2))
         Fraction(4, 5)
